# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/commanding/commanding.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2
from yamcs.protobuf.mdb import mdb_pb2 as yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/commanding/commanding.proto',
  package='yamcs.protobuf.commanding',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobuf',
  serialized_pb=b'\n*yamcs/protobuf/commanding/commanding.proto\x12\x19yamcs.protobuf.commanding\x1a\x1ayamcs/protobuf/yamcs.proto\x1a\x1cyamcs/protobuf/mdb/mdb.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"`\n\tCommandId\x12\x16\n\x0egenerationTime\x18\x01 \x02(\x03\x12\x0e\n\x06origin\x18\x02 \x02(\t\x12\x16\n\x0esequenceNumber\x18\x03 \x02(\x05\x12\x13\n\x0b\x63ommandName\x18\x04 \x01(\t\"\x8c\x03\n\x10\x43ommandQueueInfo\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x15\n\rprocessorName\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x34\n\x05state\x18\x04 \x01(\x0e\x32%.yamcs.protobuf.commanding.QueueState\x12\r\n\x05order\x18\t \x01(\x05\x12\r\n\x05users\x18\n \x03(\t\x12\x0e\n\x06groups\x18\x0b \x03(\t\x12L\n\x08minLevel\x18\x0c \x01(\x0e\x32:.yamcs.protobuf.mdb.SignificanceInfo.SignificanceLevelType\x12\x12\n\ntcPatterns\x18\r \x03(\t\x12=\n\x07\x65ntries\x18\x0e \x03(\x0b\x32,.yamcs.protobuf.commanding.CommandQueueEntry\x12\x1d\n\x15\x61\x63\x63\x65ptedCommandsCount\x18\x0f \x01(\x05\x12\x1d\n\x15rejectedCommandsCount\x18\x10 \x01(\x05\"\xea\x02\n\x11\x43ommandQueueEntry\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x15\n\rprocessorName\x18\x02 \x01(\t\x12\x11\n\tqueueName\x18\x03 \x01(\t\x12\n\n\x02id\x18\x0e \x01(\t\x12\x0e\n\x06origin\x18\x0f \x01(\t\x12\x16\n\x0esequenceNumber\x18\x10 \x01(\x05\x12\x13\n\x0b\x63ommandName\x18\x11 \x01(\t\x12\x41\n\x0b\x61ssignments\x18\x12 \x03(\x0b\x32,.yamcs.protobuf.commanding.CommandAssignment\x12\x0e\n\x06\x62inary\x18\x06 \x01(\x0c\x12\x10\n\x08username\x18\x07 \x01(\t\x12\x0f\n\x07\x63omment\x18\x0b \x01(\t\x12\x32\n\x0egenerationTime\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x1ependingTransmissionConstraints\x18\r \x01(\x08\"\xe8\x01\n\x11\x43ommandQueueEvent\x12?\n\x04type\x18\x01 \x01(\x0e\x32\x31.yamcs.protobuf.commanding.CommandQueueEvent.Type\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.yamcs.protobuf.commanding.CommandQueueEntry\"V\n\x04Type\x12\x11\n\rCOMMAND_ADDED\x10\x01\x12\x14\n\x10\x43OMMAND_REJECTED\x10\x02\x12\x10\n\x0c\x43OMMAND_SENT\x10\x03\x12\x13\n\x0f\x43OMMAND_UPDATED\x10\x04\"\xaf\x01\n\x13\x43ommandQueueRequest\x12>\n\tqueueInfo\x18\x01 \x01(\x0b\x32+.yamcs.protobuf.commanding.CommandQueueInfo\x12@\n\nqueueEntry\x18\x02 \x01(\x0b\x32,.yamcs.protobuf.commanding.CommandQueueEntry\x12\x16\n\x07rebuild\x18\x03 \x01(\x08:\x05\x66\x61lse\"i\n\x13\x43ommandSignificance\x12\x16\n\x0esequenceNumber\x18\x01 \x01(\x05\x12:\n\x0csignificance\x18\x02 \x01(\x0b\x32$.yamcs.protobuf.mdb.SignificanceInfo\"\xb5\x01\n\x0eVerifierConfig\x12\x0f\n\x07\x64isable\x18\x02 \x01(\x08\x12J\n\x0b\x63heckWindow\x18\x03 \x01(\x0b\x32\x35.yamcs.protobuf.commanding.VerifierConfig.CheckWindow\x1a\x46\n\x0b\x43heckWindow\x12\x1b\n\x13timeToStartChecking\x18\x01 \x01(\x03\x12\x1a\n\x12timeToStopChecking\x18\x02 \x01(\x03\"[\n\x17\x43ommandHistoryAttribute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.yamcs.protobuf.Value\x12\x0c\n\x04time\x18\x03 \x01(\x03\"Z\n\x11\x43ommandAssignment\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.yamcs.protobuf.Value\x12\x11\n\tuserInput\x18\x03 \x01(\x08\"\xce\x03\n\x13\x43ommandHistoryEntry\x12\n\n\x02id\x18\x07 \x01(\t\x12\x13\n\x0b\x63ommandName\x18\x08 \x01(\t\x12L\n\x07\x61liases\x18\x0c \x03(\x0b\x32;.yamcs.protobuf.commanding.CommandHistoryEntry.AliasesEntry\x12\x0e\n\x06origin\x18\t \x01(\t\x12\x16\n\x0esequenceNumber\x18\n \x01(\x05\x12\x37\n\tcommandId\x18\x01 \x01(\x0b\x32$.yamcs.protobuf.commanding.CommandId\x12@\n\x04\x61ttr\x18\x03 \x03(\x0b\x32\x32.yamcs.protobuf.commanding.CommandHistoryAttribute\x12\x32\n\x0egenerationTime\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x0b\x61ssignments\x18\x0b \x03(\x0b\x32,.yamcs.protobuf.commanding.CommandAssignment\x1a.\n\x0c\x41liasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*4\n\nQueueState\x12\x0b\n\x07\x42LOCKED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x12\x0b\n\x07\x45NABLED\x10\x03\x42\x14\n\x12org.yamcs.protobuf'
  ,
  dependencies=[yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_QUEUESTATE = _descriptor.EnumDescriptor(
  name='QueueState',
  full_name='yamcs.protobuf.commanding.QueueState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BLOCKED', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISABLED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENABLED', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2380,
  serialized_end=2432,
)
_sym_db.RegisterEnumDescriptor(_QUEUESTATE)

QueueState = enum_type_wrapper.EnumTypeWrapper(_QUEUESTATE)
BLOCKED = 1
DISABLED = 2
ENABLED = 3


_COMMANDQUEUEEVENT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.commanding.CommandQueueEvent.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMAND_ADDED', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_REJECTED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_SENT', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_UPDATED', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1173,
  serialized_end=1259,
)
_sym_db.RegisterEnumDescriptor(_COMMANDQUEUEEVENT_TYPE)


_COMMANDID = _descriptor.Descriptor(
  name='CommandId',
  full_name='yamcs.protobuf.commanding.CommandId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='generationTime', full_name='yamcs.protobuf.commanding.CommandId.generationTime', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.commanding.CommandId.origin', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.commanding.CommandId.sequenceNumber', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandName', full_name='yamcs.protobuf.commanding.CommandId.commandName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=260,
)


_COMMANDQUEUEINFO = _descriptor.Descriptor(
  name='CommandQueueInfo',
  full_name='yamcs.protobuf.commanding.CommandQueueInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.CommandQueueInfo.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processorName', full_name='yamcs.protobuf.commanding.CommandQueueInfo.processorName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.CommandQueueInfo.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.commanding.CommandQueueInfo.state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.commanding.CommandQueueInfo.order', index=4,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='yamcs.protobuf.commanding.CommandQueueInfo.users', index=5,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='yamcs.protobuf.commanding.CommandQueueInfo.groups', index=6,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minLevel', full_name='yamcs.protobuf.commanding.CommandQueueInfo.minLevel', index=7,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcPatterns', full_name='yamcs.protobuf.commanding.CommandQueueInfo.tcPatterns', index=8,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='yamcs.protobuf.commanding.CommandQueueInfo.entries', index=9,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acceptedCommandsCount', full_name='yamcs.protobuf.commanding.CommandQueueInfo.acceptedCommandsCount', index=10,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rejectedCommandsCount', full_name='yamcs.protobuf.commanding.CommandQueueInfo.rejectedCommandsCount', index=11,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=659,
)


_COMMANDQUEUEENTRY = _descriptor.Descriptor(
  name='CommandQueueEntry',
  full_name='yamcs.protobuf.commanding.CommandQueueEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.CommandQueueEntry.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processorName', full_name='yamcs.protobuf.commanding.CommandQueueEntry.processorName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queueName', full_name='yamcs.protobuf.commanding.CommandQueueEntry.queueName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.commanding.CommandQueueEntry.id', index=3,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.commanding.CommandQueueEntry.origin', index=4,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.commanding.CommandQueueEntry.sequenceNumber', index=5,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandName', full_name='yamcs.protobuf.commanding.CommandQueueEntry.commandName', index=6,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assignments', full_name='yamcs.protobuf.commanding.CommandQueueEntry.assignments', index=7,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary', full_name='yamcs.protobuf.commanding.CommandQueueEntry.binary', index=8,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.commanding.CommandQueueEntry.username', index=9,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='yamcs.protobuf.commanding.CommandQueueEntry.comment', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generationTime', full_name='yamcs.protobuf.commanding.CommandQueueEntry.generationTime', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pendingTransmissionConstraints', full_name='yamcs.protobuf.commanding.CommandQueueEntry.pendingTransmissionConstraints', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=662,
  serialized_end=1024,
)


_COMMANDQUEUEEVENT = _descriptor.Descriptor(
  name='CommandQueueEvent',
  full_name='yamcs.protobuf.commanding.CommandQueueEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.commanding.CommandQueueEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='yamcs.protobuf.commanding.CommandQueueEvent.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMMANDQUEUEEVENT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1027,
  serialized_end=1259,
)


_COMMANDQUEUEREQUEST = _descriptor.Descriptor(
  name='CommandQueueRequest',
  full_name='yamcs.protobuf.commanding.CommandQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queueInfo', full_name='yamcs.protobuf.commanding.CommandQueueRequest.queueInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queueEntry', full_name='yamcs.protobuf.commanding.CommandQueueRequest.queueEntry', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rebuild', full_name='yamcs.protobuf.commanding.CommandQueueRequest.rebuild', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1262,
  serialized_end=1437,
)


_COMMANDSIGNIFICANCE = _descriptor.Descriptor(
  name='CommandSignificance',
  full_name='yamcs.protobuf.commanding.CommandSignificance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.commanding.CommandSignificance.sequenceNumber', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='significance', full_name='yamcs.protobuf.commanding.CommandSignificance.significance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1439,
  serialized_end=1544,
)


_VERIFIERCONFIG_CHECKWINDOW = _descriptor.Descriptor(
  name='CheckWindow',
  full_name='yamcs.protobuf.commanding.VerifierConfig.CheckWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeToStartChecking', full_name='yamcs.protobuf.commanding.VerifierConfig.CheckWindow.timeToStartChecking', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeToStopChecking', full_name='yamcs.protobuf.commanding.VerifierConfig.CheckWindow.timeToStopChecking', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1658,
  serialized_end=1728,
)

_VERIFIERCONFIG = _descriptor.Descriptor(
  name='VerifierConfig',
  full_name='yamcs.protobuf.commanding.VerifierConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='disable', full_name='yamcs.protobuf.commanding.VerifierConfig.disable', index=0,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='checkWindow', full_name='yamcs.protobuf.commanding.VerifierConfig.checkWindow', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_VERIFIERCONFIG_CHECKWINDOW, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1547,
  serialized_end=1728,
)


_COMMANDHISTORYATTRIBUTE = _descriptor.Descriptor(
  name='CommandHistoryAttribute',
  full_name='yamcs.protobuf.commanding.CommandHistoryAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.CommandHistoryAttribute.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.commanding.CommandHistoryAttribute.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='yamcs.protobuf.commanding.CommandHistoryAttribute.time', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1730,
  serialized_end=1821,
)


_COMMANDASSIGNMENT = _descriptor.Descriptor(
  name='CommandAssignment',
  full_name='yamcs.protobuf.commanding.CommandAssignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.CommandAssignment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.commanding.CommandAssignment.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userInput', full_name='yamcs.protobuf.commanding.CommandAssignment.userInput', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1823,
  serialized_end=1913,
)


_COMMANDHISTORYENTRY_ALIASESENTRY = _descriptor.Descriptor(
  name='AliasesEntry',
  full_name='yamcs.protobuf.commanding.CommandHistoryEntry.AliasesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.AliasesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.AliasesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2332,
  serialized_end=2378,
)

_COMMANDHISTORYENTRY = _descriptor.Descriptor(
  name='CommandHistoryEntry',
  full_name='yamcs.protobuf.commanding.CommandHistoryEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.id', index=0,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandName', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.commandName', index=1,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aliases', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.aliases', index=2,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.origin', index=3,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.sequenceNumber', index=4,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandId', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.commandId', index=5,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attr', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.attr', index=6,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generationTime', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.generationTime', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assignments', full_name='yamcs.protobuf.commanding.CommandHistoryEntry.assignments', index=8,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDHISTORYENTRY_ALIASESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1916,
  serialized_end=2378,
)

_COMMANDQUEUEINFO.fields_by_name['state'].enum_type = _QUEUESTATE
_COMMANDQUEUEINFO.fields_by_name['minLevel'].enum_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._SIGNIFICANCEINFO_SIGNIFICANCELEVELTYPE
_COMMANDQUEUEINFO.fields_by_name['entries'].message_type = _COMMANDQUEUEENTRY
_COMMANDQUEUEENTRY.fields_by_name['assignments'].message_type = _COMMANDASSIGNMENT
_COMMANDQUEUEENTRY.fields_by_name['generationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMANDQUEUEEVENT.fields_by_name['type'].enum_type = _COMMANDQUEUEEVENT_TYPE
_COMMANDQUEUEEVENT.fields_by_name['data'].message_type = _COMMANDQUEUEENTRY
_COMMANDQUEUEEVENT_TYPE.containing_type = _COMMANDQUEUEEVENT
_COMMANDQUEUEREQUEST.fields_by_name['queueInfo'].message_type = _COMMANDQUEUEINFO
_COMMANDQUEUEREQUEST.fields_by_name['queueEntry'].message_type = _COMMANDQUEUEENTRY
_COMMANDSIGNIFICANCE.fields_by_name['significance'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._SIGNIFICANCEINFO
_VERIFIERCONFIG_CHECKWINDOW.containing_type = _VERIFIERCONFIG
_VERIFIERCONFIG.fields_by_name['checkWindow'].message_type = _VERIFIERCONFIG_CHECKWINDOW
_COMMANDHISTORYATTRIBUTE.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_COMMANDASSIGNMENT.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_COMMANDHISTORYENTRY_ALIASESENTRY.containing_type = _COMMANDHISTORYENTRY
_COMMANDHISTORYENTRY.fields_by_name['aliases'].message_type = _COMMANDHISTORYENTRY_ALIASESENTRY
_COMMANDHISTORYENTRY.fields_by_name['commandId'].message_type = _COMMANDID
_COMMANDHISTORYENTRY.fields_by_name['attr'].message_type = _COMMANDHISTORYATTRIBUTE
_COMMANDHISTORYENTRY.fields_by_name['generationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMANDHISTORYENTRY.fields_by_name['assignments'].message_type = _COMMANDASSIGNMENT
DESCRIPTOR.message_types_by_name['CommandId'] = _COMMANDID
DESCRIPTOR.message_types_by_name['CommandQueueInfo'] = _COMMANDQUEUEINFO
DESCRIPTOR.message_types_by_name['CommandQueueEntry'] = _COMMANDQUEUEENTRY
DESCRIPTOR.message_types_by_name['CommandQueueEvent'] = _COMMANDQUEUEEVENT
DESCRIPTOR.message_types_by_name['CommandQueueRequest'] = _COMMANDQUEUEREQUEST
DESCRIPTOR.message_types_by_name['CommandSignificance'] = _COMMANDSIGNIFICANCE
DESCRIPTOR.message_types_by_name['VerifierConfig'] = _VERIFIERCONFIG
DESCRIPTOR.message_types_by_name['CommandHistoryAttribute'] = _COMMANDHISTORYATTRIBUTE
DESCRIPTOR.message_types_by_name['CommandAssignment'] = _COMMANDASSIGNMENT
DESCRIPTOR.message_types_by_name['CommandHistoryEntry'] = _COMMANDHISTORYENTRY
DESCRIPTOR.enum_types_by_name['QueueState'] = _QUEUESTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CommandId = _reflection.GeneratedProtocolMessageType('CommandId', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDID,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandId)
  })
_sym_db.RegisterMessage(CommandId)

CommandQueueInfo = _reflection.GeneratedProtocolMessageType('CommandQueueInfo', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDQUEUEINFO,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandQueueInfo)
  })
_sym_db.RegisterMessage(CommandQueueInfo)

CommandQueueEntry = _reflection.GeneratedProtocolMessageType('CommandQueueEntry', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDQUEUEENTRY,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandQueueEntry)
  })
_sym_db.RegisterMessage(CommandQueueEntry)

CommandQueueEvent = _reflection.GeneratedProtocolMessageType('CommandQueueEvent', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDQUEUEEVENT,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandQueueEvent)
  })
_sym_db.RegisterMessage(CommandQueueEvent)

CommandQueueRequest = _reflection.GeneratedProtocolMessageType('CommandQueueRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDQUEUEREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandQueueRequest)
  })
_sym_db.RegisterMessage(CommandQueueRequest)

CommandSignificance = _reflection.GeneratedProtocolMessageType('CommandSignificance', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSIGNIFICANCE,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandSignificance)
  })
_sym_db.RegisterMessage(CommandSignificance)

VerifierConfig = _reflection.GeneratedProtocolMessageType('VerifierConfig', (_message.Message,), {

  'CheckWindow' : _reflection.GeneratedProtocolMessageType('CheckWindow', (_message.Message,), {
    'DESCRIPTOR' : _VERIFIERCONFIG_CHECKWINDOW,
    '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.VerifierConfig.CheckWindow)
    })
  ,
  'DESCRIPTOR' : _VERIFIERCONFIG,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.VerifierConfig)
  })
_sym_db.RegisterMessage(VerifierConfig)
_sym_db.RegisterMessage(VerifierConfig.CheckWindow)

CommandHistoryAttribute = _reflection.GeneratedProtocolMessageType('CommandHistoryAttribute', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDHISTORYATTRIBUTE,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandHistoryAttribute)
  })
_sym_db.RegisterMessage(CommandHistoryAttribute)

CommandAssignment = _reflection.GeneratedProtocolMessageType('CommandAssignment', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDASSIGNMENT,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandAssignment)
  })
_sym_db.RegisterMessage(CommandAssignment)

CommandHistoryEntry = _reflection.GeneratedProtocolMessageType('CommandHistoryEntry', (_message.Message,), {

  'AliasesEntry' : _reflection.GeneratedProtocolMessageType('AliasesEntry', (_message.Message,), {
    'DESCRIPTOR' : _COMMANDHISTORYENTRY_ALIASESENTRY,
    '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandHistoryEntry.AliasesEntry)
    })
  ,
  'DESCRIPTOR' : _COMMANDHISTORYENTRY,
  '__module__' : 'yamcs.protobuf.commanding.commanding_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.CommandHistoryEntry)
  })
_sym_db.RegisterMessage(CommandHistoryEntry)
_sym_db.RegisterMessage(CommandHistoryEntry.AliasesEntry)


DESCRIPTOR._options = None
_COMMANDHISTORYENTRY_ALIASESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/cop1/cop1.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/cop1/cop1.proto',
  package='yamcs.protobuf.cop1',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\tCop1ProtoP\001',
  serialized_pb=b'\n\x1eyamcs/protobuf/cop1/cop1.proto\x12\x13yamcs.protobuf.cop1\x1a\x1byamcs/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9a\x01\n\x11InitializeRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\x35\n\x04type\x18\x03 \x01(\x0e\x32\'.yamcs.protobuf.cop1.InitializationType\x12\"\n\x1a\x63lcwCheckInitializeTimeout\x18\x04 \x01(\x04\x12\n\n\x02vR\x18\x05 \x01(\r\"j\n\x13UpdateConfigRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\x33\n\ncop1Config\x18\x03 \x01(\x0b\x32\x1f.yamcs.protobuf.cop1.Cop1Config\"2\n\x10GetConfigRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\"2\n\x10GetStatusRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\"/\n\rResumeRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\"F\n\x0e\x44isableRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\x14\n\x0csetBypassAll\x18\x03 \x01(\x08\"x\n\x04\x43lcw\x12\x31\n\rreceptionTime\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07lockout\x18\x02 \x01(\x08\x12\x0c\n\x04wait\x18\x03 \x01(\x08\x12\x12\n\nretransmit\x18\x04 \x01(\x08\x12\n\n\x02nR\x18\x05 \x01(\r\"\x95\x02\n\nCop1Status\x12\x0c\n\x04link\x18\x0b \x01(\t\x12\x12\n\ncop1Active\x18\x01 \x01(\x08\x12\x14\n\x0csetBypassAll\x18\x02 \x01(\x08\x12\'\n\x04\x63lcw\x18\x03 \x01(\x0b\x32\x19.yamcs.protobuf.cop1.Clcw\x12-\n\x05state\x18\x04 \x01(\x0e\x32\x1e.yamcs.protobuf.cop1.Cop1State\x12\n\n\x02vS\x18\x05 \x01(\r\x12\x0b\n\x03nnR\x18\x06 \x01(\r\x12\x16\n\x0ewaitQueueNumTC\x18\x07 \x01(\r\x12\x1a\n\x12sentQueueNumFrames\x18\x08 \x01(\r\x12\x19\n\x11outQueueNumFrames\x18\t \x01(\r\x12\x0f\n\x07txCount\x18\n \x01(\r\"\x9f\x01\n\nCop1Config\x12\x0c\n\x04vcId\x18\x01 \x01(\r\x12\x1a\n\x12\x62\x64\x41\x62solutePriority\x18\x03 \x01(\x08\x12\x13\n\x0bwindowWidth\x18\x04 \x01(\r\x12\x35\n\x0btimeoutType\x18\x05 \x01(\x0e\x32 .yamcs.protobuf.cop1.TimeoutType\x12\x0f\n\x07txLimit\x18\x06 \x01(\r\x12\n\n\x02t1\x18\x07 \x01(\x04\"8\n\x16SubscribeStatusRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t*Y\n\x12InitializationType\x12\x13\n\x0fWITH_CLCW_CHECK\x10\x01\x12\x16\n\x12WITHOUT_CLCW_CHECK\x10\x02\x12\n\n\x06UNLOCK\x10\x03\x12\n\n\x06SET_VR\x10\x04*\xa7\x01\n\tCop1State\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x1b\n\x17RETRANSMIT_WITHOUT_WAIT\x10\x02\x12\x18\n\x14RETRANSMIT_WITH_WAIT\x10\x03\x12\x1b\n\x17INITIALIZING_WITHOUT_BC\x10\x04\x12\x18\n\x14INITIALIZING_WITH_BC\x10\x05\x12\x11\n\rUNINITIALIZED\x10\x06\x12\r\n\tSUSPENDED\x10\x07*,\n\x0bTimeoutType\x12\x10\n\x0cUNINITIALIZE\x10\x00\x12\x0b\n\x07SUSPEND\x10\x01\x32\xf8\x06\n\x07\x43op1Api\x12}\n\nInitialize\x12&.yamcs.protobuf.cop1.InitializeRequest\x1a\x16.google.protobuf.Empty\"/\x8a\x92\x03+\x1a&/api/cop1/{instance}/{link}:initialize:\x01*\x12n\n\x06Resume\x12\".yamcs.protobuf.cop1.ResumeRequest\x1a\x16.google.protobuf.Empty\"(\x8a\x92\x03$\x1a\"/api/cop1/{instance}/{link}:resume\x12t\n\x07\x44isable\x12#.yamcs.protobuf.cop1.DisableRequest\x1a\x16.google.protobuf.Empty\",\x8a\x92\x03(\x1a#/api/cop1/{instance}/{link}:disable:\x01*\x12\x8f\x01\n\x0cUpdateConfig\x12(.yamcs.protobuf.cop1.UpdateConfigRequest\x1a\x1f.yamcs.protobuf.cop1.Cop1Config\"4\x8a\x92\x03\x30*\"/api/cop1/{instance}/{link}/config:\ncop1Config\x12}\n\tGetConfig\x12%.yamcs.protobuf.cop1.GetConfigRequest\x1a\x1f.yamcs.protobuf.cop1.Cop1Config\"(\x8a\x92\x03$\n\"/api/cop1/{instance}/{link}/config\x12}\n\tGetStatus\x12%.yamcs.protobuf.cop1.GetStatusRequest\x1a\x1f.yamcs.protobuf.cop1.Cop1Status\"(\x8a\x92\x03$\n\"/api/cop1/{instance}/{link}/status\x12m\n\x0fSubscribeStatus\x12+.yamcs.protobuf.cop1.SubscribeStatusRequest\x1a\x1f.yamcs.protobuf.cop1.Cop1Status\"\n\xda\x92\x03\x06\n\x04\x63op10\x01\x1a\t\x82\x80\x01\x05\x43OP-1B!\n\x12org.yamcs.protobufB\tCop1ProtoP\x01'
  ,
  dependencies=[yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_INITIALIZATIONTYPE = _descriptor.EnumDescriptor(
  name='InitializationType',
  full_name='yamcs.protobuf.cop1.InitializationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WITH_CLCW_CHECK', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHOUT_CLCW_CHECK', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNLOCK', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_VR', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1258,
  serialized_end=1347,
)
_sym_db.RegisterEnumDescriptor(_INITIALIZATIONTYPE)

InitializationType = enum_type_wrapper.EnumTypeWrapper(_INITIALIZATIONTYPE)
_COP1STATE = _descriptor.EnumDescriptor(
  name='Cop1State',
  full_name='yamcs.protobuf.cop1.Cop1State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RETRANSMIT_WITHOUT_WAIT', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RETRANSMIT_WITH_WAIT', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING_WITHOUT_BC', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING_WITH_BC', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNINITIALIZED', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUSPENDED', index=6, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1350,
  serialized_end=1517,
)
_sym_db.RegisterEnumDescriptor(_COP1STATE)

Cop1State = enum_type_wrapper.EnumTypeWrapper(_COP1STATE)
_TIMEOUTTYPE = _descriptor.EnumDescriptor(
  name='TimeoutType',
  full_name='yamcs.protobuf.cop1.TimeoutType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNINITIALIZE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUSPEND', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1519,
  serialized_end=1563,
)
_sym_db.RegisterEnumDescriptor(_TIMEOUTTYPE)

TimeoutType = enum_type_wrapper.EnumTypeWrapper(_TIMEOUTTYPE)
WITH_CLCW_CHECK = 1
WITHOUT_CLCW_CHECK = 2
UNLOCK = 3
SET_VR = 4
ACTIVE = 1
RETRANSMIT_WITHOUT_WAIT = 2
RETRANSMIT_WITH_WAIT = 3
INITIALIZING_WITHOUT_BC = 4
INITIALIZING_WITH_BC = 5
UNINITIALIZED = 6
SUSPENDED = 7
UNINITIALIZE = 0
SUSPEND = 1



_INITIALIZEREQUEST = _descriptor.Descriptor(
  name='InitializeRequest',
  full_name='yamcs.protobuf.cop1.InitializeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cop1.InitializeRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.InitializeRequest.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.cop1.InitializeRequest.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clcwCheckInitializeTimeout', full_name='yamcs.protobuf.cop1.InitializeRequest.clcwCheckInitializeTimeout', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vR', full_name='yamcs.protobuf.cop1.InitializeRequest.vR', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=301,
)


_UPDATECONFIGREQUEST = _descriptor.Descriptor(
  name='UpdateConfigRequest',
  full_name='yamcs.protobuf.cop1.UpdateConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cop1.UpdateConfigRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.UpdateConfigRequest.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cop1Config', full_name='yamcs.protobuf.cop1.UpdateConfigRequest.cop1Config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=409,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='yamcs.protobuf.cop1.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cop1.GetConfigRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.GetConfigRequest.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=411,
  serialized_end=461,
)


_GETSTATUSREQUEST = _descriptor.Descriptor(
  name='GetStatusRequest',
  full_name='yamcs.protobuf.cop1.GetStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cop1.GetStatusRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.GetStatusRequest.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=513,
)


_RESUMEREQUEST = _descriptor.Descriptor(
  name='ResumeRequest',
  full_name='yamcs.protobuf.cop1.ResumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cop1.ResumeRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.ResumeRequest.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=562,
)


_DISABLEREQUEST = _descriptor.Descriptor(
  name='DisableRequest',
  full_name='yamcs.protobuf.cop1.DisableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cop1.DisableRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.DisableRequest.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='setBypassAll', full_name='yamcs.protobuf.cop1.DisableRequest.setBypassAll', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=634,
)


_CLCW = _descriptor.Descriptor(
  name='Clcw',
  full_name='yamcs.protobuf.cop1.Clcw',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='receptionTime', full_name='yamcs.protobuf.cop1.Clcw.receptionTime', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lockout', full_name='yamcs.protobuf.cop1.Clcw.lockout', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wait', full_name='yamcs.protobuf.cop1.Clcw.wait', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retransmit', full_name='yamcs.protobuf.cop1.Clcw.retransmit', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nR', full_name='yamcs.protobuf.cop1.Clcw.nR', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=636,
  serialized_end=756,
)


_COP1STATUS = _descriptor.Descriptor(
  name='Cop1Status',
  full_name='yamcs.protobuf.cop1.Cop1Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.Cop1Status.link', index=0,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cop1Active', full_name='yamcs.protobuf.cop1.Cop1Status.cop1Active', index=1,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='setBypassAll', full_name='yamcs.protobuf.cop1.Cop1Status.setBypassAll', index=2,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clcw', full_name='yamcs.protobuf.cop1.Cop1Status.clcw', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.cop1.Cop1Status.state', index=4,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vS', full_name='yamcs.protobuf.cop1.Cop1Status.vS', index=5,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nnR', full_name='yamcs.protobuf.cop1.Cop1Status.nnR', index=6,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waitQueueNumTC', full_name='yamcs.protobuf.cop1.Cop1Status.waitQueueNumTC', index=7,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sentQueueNumFrames', full_name='yamcs.protobuf.cop1.Cop1Status.sentQueueNumFrames', index=8,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outQueueNumFrames', full_name='yamcs.protobuf.cop1.Cop1Status.outQueueNumFrames', index=9,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txCount', full_name='yamcs.protobuf.cop1.Cop1Status.txCount', index=10,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=759,
  serialized_end=1036,
)


_COP1CONFIG = _descriptor.Descriptor(
  name='Cop1Config',
  full_name='yamcs.protobuf.cop1.Cop1Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vcId', full_name='yamcs.protobuf.cop1.Cop1Config.vcId', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bdAbsolutePriority', full_name='yamcs.protobuf.cop1.Cop1Config.bdAbsolutePriority', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='windowWidth', full_name='yamcs.protobuf.cop1.Cop1Config.windowWidth', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeoutType', full_name='yamcs.protobuf.cop1.Cop1Config.timeoutType', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txLimit', full_name='yamcs.protobuf.cop1.Cop1Config.txLimit', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='t1', full_name='yamcs.protobuf.cop1.Cop1Config.t1', index=5,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1039,
  serialized_end=1198,
)


_SUBSCRIBESTATUSREQUEST = _descriptor.Descriptor(
  name='SubscribeStatusRequest',
  full_name='yamcs.protobuf.cop1.SubscribeStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cop1.SubscribeStatusRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.cop1.SubscribeStatusRequest.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1200,
  serialized_end=1256,
)

_INITIALIZEREQUEST.fields_by_name['type'].enum_type = _INITIALIZATIONTYPE
_UPDATECONFIGREQUEST.fields_by_name['cop1Config'].message_type = _COP1CONFIG
_CLCW.fields_by_name['receptionTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COP1STATUS.fields_by_name['clcw'].message_type = _CLCW
_COP1STATUS.fields_by_name['state'].enum_type = _COP1STATE
_COP1CONFIG.fields_by_name['timeoutType'].enum_type = _TIMEOUTTYPE
DESCRIPTOR.message_types_by_name['InitializeRequest'] = _INITIALIZEREQUEST
DESCRIPTOR.message_types_by_name['UpdateConfigRequest'] = _UPDATECONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetStatusRequest'] = _GETSTATUSREQUEST
DESCRIPTOR.message_types_by_name['ResumeRequest'] = _RESUMEREQUEST
DESCRIPTOR.message_types_by_name['DisableRequest'] = _DISABLEREQUEST
DESCRIPTOR.message_types_by_name['Clcw'] = _CLCW
DESCRIPTOR.message_types_by_name['Cop1Status'] = _COP1STATUS
DESCRIPTOR.message_types_by_name['Cop1Config'] = _COP1CONFIG
DESCRIPTOR.message_types_by_name['SubscribeStatusRequest'] = _SUBSCRIBESTATUSREQUEST
DESCRIPTOR.enum_types_by_name['InitializationType'] = _INITIALIZATIONTYPE
DESCRIPTOR.enum_types_by_name['Cop1State'] = _COP1STATE
DESCRIPTOR.enum_types_by_name['TimeoutType'] = _TIMEOUTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InitializeRequest = _reflection.GeneratedProtocolMessageType('InitializeRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITIALIZEREQUEST,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.InitializeRequest)
  })
_sym_db.RegisterMessage(InitializeRequest)

UpdateConfigRequest = _reflection.GeneratedProtocolMessageType('UpdateConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONFIGREQUEST,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.UpdateConfigRequest)
  })
_sym_db.RegisterMessage(UpdateConfigRequest)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGREQUEST,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.GetConfigRequest)
  })
_sym_db.RegisterMessage(GetConfigRequest)

GetStatusRequest = _reflection.GeneratedProtocolMessageType('GetStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATUSREQUEST,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.GetStatusRequest)
  })
_sym_db.RegisterMessage(GetStatusRequest)

ResumeRequest = _reflection.GeneratedProtocolMessageType('ResumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEREQUEST,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.ResumeRequest)
  })
_sym_db.RegisterMessage(ResumeRequest)

DisableRequest = _reflection.GeneratedProtocolMessageType('DisableRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISABLEREQUEST,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.DisableRequest)
  })
_sym_db.RegisterMessage(DisableRequest)

Clcw = _reflection.GeneratedProtocolMessageType('Clcw', (_message.Message,), {
  'DESCRIPTOR' : _CLCW,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.Clcw)
  })
_sym_db.RegisterMessage(Clcw)

Cop1Status = _reflection.GeneratedProtocolMessageType('Cop1Status', (_message.Message,), {
  'DESCRIPTOR' : _COP1STATUS,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.Cop1Status)
  })
_sym_db.RegisterMessage(Cop1Status)

Cop1Config = _reflection.GeneratedProtocolMessageType('Cop1Config', (_message.Message,), {
  'DESCRIPTOR' : _COP1CONFIG,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.Cop1Config)
  })
_sym_db.RegisterMessage(Cop1Config)

SubscribeStatusRequest = _reflection.GeneratedProtocolMessageType('SubscribeStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBESTATUSREQUEST,
  '__module__' : 'yamcs.protobuf.cop1.cop1_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cop1.SubscribeStatusRequest)
  })
_sym_db.RegisterMessage(SubscribeStatusRequest)


DESCRIPTOR._options = None

_COP1API = _descriptor.ServiceDescriptor(
  name='Cop1Api',
  full_name='yamcs.protobuf.cop1.Cop1Api',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\200\001\005COP-1',
  serialized_start=1566,
  serialized_end=2454,
  methods=[
  _descriptor.MethodDescriptor(
    name='Initialize',
    full_name='yamcs.protobuf.cop1.Cop1Api.Initialize',
    index=0,
    containing_service=None,
    input_type=_INITIALIZEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003+\032&/api/cop1/{instance}/{link}:initialize:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='Resume',
    full_name='yamcs.protobuf.cop1.Cop1Api.Resume',
    index=1,
    containing_service=None,
    input_type=_RESUMEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003$\032\"/api/cop1/{instance}/{link}:resume',
  ),
  _descriptor.MethodDescriptor(
    name='Disable',
    full_name='yamcs.protobuf.cop1.Cop1Api.Disable',
    index=2,
    containing_service=None,
    input_type=_DISABLEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003(\032#/api/cop1/{instance}/{link}:disable:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateConfig',
    full_name='yamcs.protobuf.cop1.Cop1Api.UpdateConfig',
    index=3,
    containing_service=None,
    input_type=_UPDATECONFIGREQUEST,
    output_type=_COP1CONFIG,
    serialized_options=b'\212\222\0030*\"/api/cop1/{instance}/{link}/config:\ncop1Config',
  ),
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='yamcs.protobuf.cop1.Cop1Api.GetConfig',
    index=4,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_COP1CONFIG,
    serialized_options=b'\212\222\003$\n\"/api/cop1/{instance}/{link}/config',
  ),
  _descriptor.MethodDescriptor(
    name='GetStatus',
    full_name='yamcs.protobuf.cop1.Cop1Api.GetStatus',
    index=5,
    containing_service=None,
    input_type=_GETSTATUSREQUEST,
    output_type=_COP1STATUS,
    serialized_options=b'\212\222\003$\n\"/api/cop1/{instance}/{link}/status',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeStatus',
    full_name='yamcs.protobuf.cop1.Cop1Api.SubscribeStatus',
    index=6,
    containing_service=None,
    input_type=_SUBSCRIBESTATUSREQUEST,
    output_type=_COP1STATUS,
    serialized_options=b'\332\222\003\006\n\004cop1',
  ),
])
_sym_db.RegisterServiceDescriptor(_COP1API)

DESCRIPTOR.services_by_name['Cop1Api'] = _COP1API

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/processing/mdb_override_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.mdb import mdb_pb2 as yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/processing/mdb_override_service.proto',
  package='yamcs.protobuf.processing',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\027MdbOverrideServiceProtoP\001',
  serialized_pb=b'\n4yamcs/protobuf/processing/mdb_override_service.proto\x12\x19yamcs.protobuf.processing\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\x1a\x1cyamcs/protobuf/mdb/mdb.proto\"A\n\x1aSubscribeMdbChangesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\">\n\x17ListMdbOverridesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"Y\n\x18ListMdbOverridesResponse\x12=\n\toverrides\x18\x01 \x03(\x0b\x32*.yamcs.protobuf.processing.MdbOverrideInfo\"Q\n\x1cGetAlgorithmOverridesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"g\n\x1dGetAlgorithmOverridesResponse\x12\x46\n\x0ctextOverride\x18\x01 \x01(\x0b\x32\x30.yamcs.protobuf.processing.AlgorithmTextOverride\"P\n\x1bGetParameterOverrideRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x9e\x02\n\x11ParameterOverride\x12\x11\n\tparameter\x18\x01 \x01(\t\x12=\n\x11\x64\x65\x66\x61ultCalibrator\x18\x05 \x01(\x0b\x32\".yamcs.protobuf.mdb.CalibratorInfo\x12\x45\n\x12\x63ontextCalibrators\x18\x06 \x03(\x0b\x32).yamcs.protobuf.mdb.ContextCalibratorInfo\x12\x33\n\x0c\x64\x65\x66\x61ultAlarm\x18\x07 \x01(\x0b\x32\x1d.yamcs.protobuf.mdb.AlarmInfo\x12;\n\rcontextAlarms\x18\x08 \x03(\x0b\x32$.yamcs.protobuf.mdb.ContextAlarmInfo\"\xa5\x02\n\x0fMdbOverrideInfo\x12\x45\n\x04type\x18\x01 \x01(\x0e\x32\x37.yamcs.protobuf.processing.MdbOverrideInfo.OverrideType\x12O\n\x15\x61lgorithmTextOverride\x18\x02 \x01(\x0b\x32\x30.yamcs.protobuf.processing.AlgorithmTextOverride\x12G\n\x11parameterOverride\x18\x03 \x01(\x0b\x32,.yamcs.protobuf.processing.ParameterOverride\"1\n\x0cOverrideType\x12\x12\n\x0e\x41LGORITHM_TEXT\x10\x00\x12\r\n\tPARAMETER\x10\x01\"8\n\x15\x41lgorithmTextOverride\x12\x11\n\talgorithm\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"\xab\x04\n\x16UpdateParameterRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12L\n\x06\x61\x63tion\x18\x04 \x01(\x0e\x32<.yamcs.protobuf.processing.UpdateParameterRequest.ActionType\x12=\n\x11\x64\x65\x66\x61ultCalibrator\x18\x05 \x01(\x0b\x32\".yamcs.protobuf.mdb.CalibratorInfo\x12\x44\n\x11\x63ontextCalibrator\x18\x06 \x03(\x0b\x32).yamcs.protobuf.mdb.ContextCalibratorInfo\x12\x33\n\x0c\x64\x65\x66\x61ultAlarm\x18\x07 \x01(\x0b\x32\x1d.yamcs.protobuf.mdb.AlarmInfo\x12:\n\x0c\x63ontextAlarm\x18\x08 \x03(\x0b\x32$.yamcs.protobuf.mdb.ContextAlarmInfo\"\x99\x01\n\nActionType\x12\t\n\x05RESET\x10\x00\x12\x15\n\x11RESET_CALIBRATORS\x10\x01\x12\x1a\n\x16SET_DEFAULT_CALIBRATOR\x10\x02\x12\x13\n\x0fSET_CALIBRATORS\x10\x03\x12\x10\n\x0cRESET_ALARMS\x10\x04\x12\x16\n\x12SET_DEFAULT_ALARMS\x10\x05\x12\x0e\n\nSET_ALARMS\x10\x06\"\xf1\x01\n\x16UpdateAlgorithmRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12L\n\x06\x61\x63tion\x18\x04 \x01(\x0e\x32<.yamcs.protobuf.processing.UpdateAlgorithmRequest.ActionType\x12\x34\n\talgorithm\x18\x06 \x01(\x0b\x32!.yamcs.protobuf.mdb.AlgorithmInfo\" \n\nActionType\x12\t\n\x05RESET\x10\x00\x12\x07\n\x03SET\x10\x01\x32\xc2\t\n\x0eMdbOverrideApi\x12\xac\x01\n\x10ListMdbOverrides\x12\x32.yamcs.protobuf.processing.ListMdbOverridesRequest\x1a\x33.yamcs.protobuf.processing.ListMdbOverridesResponse\"/\x8a\x92\x03+\n)/api/mdb-overrides/{instance}/{processor}\x12\xce\x01\n\x15GetAlgorithmOverrides\x12\x37.yamcs.protobuf.processing.GetAlgorithmOverridesRequest\x1a\x38.yamcs.protobuf.processing.GetAlgorithmOverridesResponse\"B\x8a\x92\x03>\n</api/mdb-overrides/{instance}/{processor}/algorithms/{name*}\x12\xc0\x01\n\x14GetParameterOverride\x12\x36.yamcs.protobuf.processing.GetParameterOverrideRequest\x1a,.yamcs.protobuf.processing.ParameterOverride\"B\x8a\x92\x03>\n</api/mdb-overrides/{instance}/{processor}/parameters/{name*}\x12\xeb\x01\n\x0fUpdateParameter\x12\x31.yamcs.protobuf.processing.UpdateParameterRequest\x1a%.yamcs.protobuf.mdb.ParameterTypeInfo\"~\x8a\x92\x03z*</api/mdb-overrides/{instance}/{processor}/parameters/{name*}:\x01*Z7*2/api/mdb/{instance}/{processor}/parameters/{name*}:\x01*\x12\xdc\x01\n\x0fUpdateAlgorithm\x12\x31.yamcs.protobuf.processing.UpdateAlgorithmRequest\x1a\x16.google.protobuf.Empty\"~\x8a\x92\x03z*</api/mdb-overrides/{instance}/{processor}/algorithms/{name*}:\x01*Z7*2/api/mdb/{instance}/{processor}/algorithms/{name*}:\x01*\x12\x8d\x01\n\x13SubscribeMdbChanges\x12\x35.yamcs.protobuf.processing.SubscribeMdbChangesRequest\x1a*.yamcs.protobuf.processing.MdbOverrideInfo\"\x11\xda\x92\x03\r\n\x0bmdb-changes0\x01\x1a\x10\x82\x80\x01\x0cMDB OverrideB/\n\x12org.yamcs.protobufB\x17MdbOverrideServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2.DESCRIPTOR,])



_MDBOVERRIDEINFO_OVERRIDETYPE = _descriptor.EnumDescriptor(
  name='OverrideType',
  full_name='yamcs.protobuf.processing.MdbOverrideInfo.OverrideType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALGORITHM_TEXT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARAMETER', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1197,
  serialized_end=1246,
)
_sym_db.RegisterEnumDescriptor(_MDBOVERRIDEINFO_OVERRIDETYPE)

_UPDATEPARAMETERREQUEST_ACTIONTYPE = _descriptor.EnumDescriptor(
  name='ActionType',
  full_name='yamcs.protobuf.processing.UpdateParameterRequest.ActionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESET_CALIBRATORS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_DEFAULT_CALIBRATOR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_CALIBRATORS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESET_ALARMS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_DEFAULT_ALARMS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_ALARMS', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1709,
  serialized_end=1862,
)
_sym_db.RegisterEnumDescriptor(_UPDATEPARAMETERREQUEST_ACTIONTYPE)

_UPDATEALGORITHMREQUEST_ACTIONTYPE = _descriptor.EnumDescriptor(
  name='ActionType',
  full_name='yamcs.protobuf.processing.UpdateAlgorithmRequest.ActionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2074,
  serialized_end=2106,
)
_sym_db.RegisterEnumDescriptor(_UPDATEALGORITHMREQUEST_ACTIONTYPE)


_SUBSCRIBEMDBCHANGESREQUEST = _descriptor.Descriptor(
  name='SubscribeMdbChangesRequest',
  full_name='yamcs.protobuf.processing.SubscribeMdbChangesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.SubscribeMdbChangesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.SubscribeMdbChangesRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=236,
)


_LISTMDBOVERRIDESREQUEST = _descriptor.Descriptor(
  name='ListMdbOverridesRequest',
  full_name='yamcs.protobuf.processing.ListMdbOverridesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.ListMdbOverridesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.ListMdbOverridesRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=300,
)


_LISTMDBOVERRIDESRESPONSE = _descriptor.Descriptor(
  name='ListMdbOverridesResponse',
  full_name='yamcs.protobuf.processing.ListMdbOverridesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='overrides', full_name='yamcs.protobuf.processing.ListMdbOverridesResponse.overrides', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=391,
)


_GETALGORITHMOVERRIDESREQUEST = _descriptor.Descriptor(
  name='GetAlgorithmOverridesRequest',
  full_name='yamcs.protobuf.processing.GetAlgorithmOverridesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.GetAlgorithmOverridesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.GetAlgorithmOverridesRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.GetAlgorithmOverridesRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=474,
)


_GETALGORITHMOVERRIDESRESPONSE = _descriptor.Descriptor(
  name='GetAlgorithmOverridesResponse',
  full_name='yamcs.protobuf.processing.GetAlgorithmOverridesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='textOverride', full_name='yamcs.protobuf.processing.GetAlgorithmOverridesResponse.textOverride', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=476,
  serialized_end=579,
)


_GETPARAMETEROVERRIDEREQUEST = _descriptor.Descriptor(
  name='GetParameterOverrideRequest',
  full_name='yamcs.protobuf.processing.GetParameterOverrideRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.GetParameterOverrideRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.GetParameterOverrideRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.GetParameterOverrideRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=661,
)


_PARAMETEROVERRIDE = _descriptor.Descriptor(
  name='ParameterOverride',
  full_name='yamcs.protobuf.processing.ParameterOverride',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.processing.ParameterOverride.parameter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultCalibrator', full_name='yamcs.protobuf.processing.ParameterOverride.defaultCalibrator', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contextCalibrators', full_name='yamcs.protobuf.processing.ParameterOverride.contextCalibrators', index=2,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultAlarm', full_name='yamcs.protobuf.processing.ParameterOverride.defaultAlarm', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contextAlarms', full_name='yamcs.protobuf.processing.ParameterOverride.contextAlarms', index=4,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=664,
  serialized_end=950,
)


_MDBOVERRIDEINFO = _descriptor.Descriptor(
  name='MdbOverrideInfo',
  full_name='yamcs.protobuf.processing.MdbOverrideInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.processing.MdbOverrideInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithmTextOverride', full_name='yamcs.protobuf.processing.MdbOverrideInfo.algorithmTextOverride', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterOverride', full_name='yamcs.protobuf.processing.MdbOverrideInfo.parameterOverride', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MDBOVERRIDEINFO_OVERRIDETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=953,
  serialized_end=1246,
)


_ALGORITHMTEXTOVERRIDE = _descriptor.Descriptor(
  name='AlgorithmTextOverride',
  full_name='yamcs.protobuf.processing.AlgorithmTextOverride',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='yamcs.protobuf.processing.AlgorithmTextOverride.algorithm', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='yamcs.protobuf.processing.AlgorithmTextOverride.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1248,
  serialized_end=1304,
)


_UPDATEPARAMETERREQUEST = _descriptor.Descriptor(
  name='UpdateParameterRequest',
  full_name='yamcs.protobuf.processing.UpdateParameterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.UpdateParameterRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.UpdateParameterRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.UpdateParameterRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='yamcs.protobuf.processing.UpdateParameterRequest.action', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultCalibrator', full_name='yamcs.protobuf.processing.UpdateParameterRequest.defaultCalibrator', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contextCalibrator', full_name='yamcs.protobuf.processing.UpdateParameterRequest.contextCalibrator', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultAlarm', full_name='yamcs.protobuf.processing.UpdateParameterRequest.defaultAlarm', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contextAlarm', full_name='yamcs.protobuf.processing.UpdateParameterRequest.contextAlarm', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UPDATEPARAMETERREQUEST_ACTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1307,
  serialized_end=1862,
)


_UPDATEALGORITHMREQUEST = _descriptor.Descriptor(
  name='UpdateAlgorithmRequest',
  full_name='yamcs.protobuf.processing.UpdateAlgorithmRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.UpdateAlgorithmRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.UpdateAlgorithmRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.UpdateAlgorithmRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='yamcs.protobuf.processing.UpdateAlgorithmRequest.action', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='yamcs.protobuf.processing.UpdateAlgorithmRequest.algorithm', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UPDATEALGORITHMREQUEST_ACTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1865,
  serialized_end=2106,
)

_LISTMDBOVERRIDESRESPONSE.fields_by_name['overrides'].message_type = _MDBOVERRIDEINFO
_GETALGORITHMOVERRIDESRESPONSE.fields_by_name['textOverride'].message_type = _ALGORITHMTEXTOVERRIDE
_PARAMETEROVERRIDE.fields_by_name['defaultCalibrator'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._CALIBRATORINFO
_PARAMETEROVERRIDE.fields_by_name['contextCalibrators'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._CONTEXTCALIBRATORINFO
_PARAMETEROVERRIDE.fields_by_name['defaultAlarm'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._ALARMINFO
_PARAMETEROVERRIDE.fields_by_name['contextAlarms'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._CONTEXTALARMINFO
_MDBOVERRIDEINFO.fields_by_name['type'].enum_type = _MDBOVERRIDEINFO_OVERRIDETYPE
_MDBOVERRIDEINFO.fields_by_name['algorithmTextOverride'].message_type = _ALGORITHMTEXTOVERRIDE
_MDBOVERRIDEINFO.fields_by_name['parameterOverride'].message_type = _PARAMETEROVERRIDE
_MDBOVERRIDEINFO_OVERRIDETYPE.containing_type = _MDBOVERRIDEINFO
_UPDATEPARAMETERREQUEST.fields_by_name['action'].enum_type = _UPDATEPARAMETERREQUEST_ACTIONTYPE
_UPDATEPARAMETERREQUEST.fields_by_name['defaultCalibrator'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._CALIBRATORINFO
_UPDATEPARAMETERREQUEST.fields_by_name['contextCalibrator'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._CONTEXTCALIBRATORINFO
_UPDATEPARAMETERREQUEST.fields_by_name['defaultAlarm'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._ALARMINFO
_UPDATEPARAMETERREQUEST.fields_by_name['contextAlarm'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._CONTEXTALARMINFO
_UPDATEPARAMETERREQUEST_ACTIONTYPE.containing_type = _UPDATEPARAMETERREQUEST
_UPDATEALGORITHMREQUEST.fields_by_name['action'].enum_type = _UPDATEALGORITHMREQUEST_ACTIONTYPE
_UPDATEALGORITHMREQUEST.fields_by_name['algorithm'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._ALGORITHMINFO
_UPDATEALGORITHMREQUEST_ACTIONTYPE.containing_type = _UPDATEALGORITHMREQUEST
DESCRIPTOR.message_types_by_name['SubscribeMdbChangesRequest'] = _SUBSCRIBEMDBCHANGESREQUEST
DESCRIPTOR.message_types_by_name['ListMdbOverridesRequest'] = _LISTMDBOVERRIDESREQUEST
DESCRIPTOR.message_types_by_name['ListMdbOverridesResponse'] = _LISTMDBOVERRIDESRESPONSE
DESCRIPTOR.message_types_by_name['GetAlgorithmOverridesRequest'] = _GETALGORITHMOVERRIDESREQUEST
DESCRIPTOR.message_types_by_name['GetAlgorithmOverridesResponse'] = _GETALGORITHMOVERRIDESRESPONSE
DESCRIPTOR.message_types_by_name['GetParameterOverrideRequest'] = _GETPARAMETEROVERRIDEREQUEST
DESCRIPTOR.message_types_by_name['ParameterOverride'] = _PARAMETEROVERRIDE
DESCRIPTOR.message_types_by_name['MdbOverrideInfo'] = _MDBOVERRIDEINFO
DESCRIPTOR.message_types_by_name['AlgorithmTextOverride'] = _ALGORITHMTEXTOVERRIDE
DESCRIPTOR.message_types_by_name['UpdateParameterRequest'] = _UPDATEPARAMETERREQUEST
DESCRIPTOR.message_types_by_name['UpdateAlgorithmRequest'] = _UPDATEALGORITHMREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubscribeMdbChangesRequest = _reflection.GeneratedProtocolMessageType('SubscribeMdbChangesRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEMDBCHANGESREQUEST,
  '__module__' : 'yamcs.protobuf.processing.mdb_override_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.SubscribeMdbChangesRequest)
  })
_sym_db.RegisterMessage(SubscribeMdbChangesRequest)

ListMdbOverridesRequest = _reflection.GeneratedProtocolMessageType('ListMdbOverridesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMDBOVERRIDESREQUEST,
  '__module__' : 'yamcs.protobuf.processing.mdb_override_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.ListMdbOverridesRequest)
  })
_sym_db.RegisterMessage(ListMdbOverridesRequest)

ListMdbOverridesResponse = _reflection.GeneratedProtocolMessageType('ListMdbOverridesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMDBOVERRIDESRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.mdb_override_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.ListMdbOverridesResponse)
  })
_sym_db.RegisterMessage(ListMdbOverridesResponse)

GetAlgorithmOverridesRequest = _reflection.GeneratedProtocolMessageType('GetAlgorithmOverridesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALGORITHMOVERRIDESREQUEST,
  '__module__' : 'yamcs.protobuf.processing.mdb_override_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.GetAlgorithmOverridesRequest)
  })
_sym_db.RegisterMessage(GetAlgorithmOverridesRequest)

GetAlgorithmOverridesResponse = _reflection.GeneratedProtocolMessageType('GetAlgorithmOverridesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALGORITHMOVERRIDESRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.mdb_override_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.GetAlgorithmOverridesResponse)
  })
_sym_db.RegisterMessage(GetAlgorithmOverridesResponse)

GetParameterOverrideRequest = _reflection.GeneratedProtocolMessageType('GetParameterOverrideRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPARAMETEROVERRIDEREQUEST,
  '__module__' : 'yamcs.protobuf.processing.mdb_override_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.GetParameterOverrideRequest)
  })
_sym_db.RegisterMessage(GetParameterOverrideRequest)

ParameterOverride = _reflection.GeneratedProtocolMessageType('ParameterOverride', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETEROVERRIDE,
  '__module__' : 'yamcs.protobuf.processing.mdb_override_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.ParameterOverride)
  })
_sym_db.RegisterMessage(ParameterOverride)

MdbOverrideInfo = _reflection.GeneratedProtocolMessageType('MdbOverrideInfo', (_message.Message,), {
  'DESCRIPTOR' : _MDBOVERRIDEINFO,
  '__module__' : 'yamcs.protobuf.processing.mdb_override_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.MdbOverrideInfo)
  })
_sym_db.RegisterMessage(MdbOverrideInfo)

AlgorithmTextOverride = _reflection.GeneratedProtocolMessageType('AlgorithmTextOverride', (_message.Message,), {
  'DESCRIPTOR' : _ALGORITHMTEXTOVERRIDE,
  '__module__' : 'yamcs.protobuf.processing.mdb_override_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.AlgorithmTextOverride)
  })
_sym_db.RegisterMessage(AlgorithmTextOverride)

UpdateParameterRequest = _reflection.GeneratedProtocolMessageType('UpdateParameterRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPARAMETERREQUEST,
  '__module__' : 'yamcs.protobuf.processing.mdb_override_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.UpdateParameterRequest)
  })
_sym_db.RegisterMessage(UpdateParameterRequest)

UpdateAlgorithmRequest = _reflection.GeneratedProtocolMessageType('UpdateAlgorithmRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALGORITHMREQUEST,
  '__module__' : 'yamcs.protobuf.processing.mdb_override_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.UpdateAlgorithmRequest)
  })
_sym_db.RegisterMessage(UpdateAlgorithmRequest)


DESCRIPTOR._options = None

_MDBOVERRIDEAPI = _descriptor.ServiceDescriptor(
  name='MdbOverrideApi',
  full_name='yamcs.protobuf.processing.MdbOverrideApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\200\001\014MDB Override',
  serialized_start=2109,
  serialized_end=3327,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListMdbOverrides',
    full_name='yamcs.protobuf.processing.MdbOverrideApi.ListMdbOverrides',
    index=0,
    containing_service=None,
    input_type=_LISTMDBOVERRIDESREQUEST,
    output_type=_LISTMDBOVERRIDESRESPONSE,
    serialized_options=b'\212\222\003+\n)/api/mdb-overrides/{instance}/{processor}',
  ),
  _descriptor.MethodDescriptor(
    name='GetAlgorithmOverrides',
    full_name='yamcs.protobuf.processing.MdbOverrideApi.GetAlgorithmOverrides',
    index=1,
    containing_service=None,
    input_type=_GETALGORITHMOVERRIDESREQUEST,
    output_type=_GETALGORITHMOVERRIDESRESPONSE,
    serialized_options=b'\212\222\003>\n</api/mdb-overrides/{instance}/{processor}/algorithms/{name*}',
  ),
  _descriptor.MethodDescriptor(
    name='GetParameterOverride',
    full_name='yamcs.protobuf.processing.MdbOverrideApi.GetParameterOverride',
    index=2,
    containing_service=None,
    input_type=_GETPARAMETEROVERRIDEREQUEST,
    output_type=_PARAMETEROVERRIDE,
    serialized_options=b'\212\222\003>\n</api/mdb-overrides/{instance}/{processor}/parameters/{name*}',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateParameter',
    full_name='yamcs.protobuf.processing.MdbOverrideApi.UpdateParameter',
    index=3,
    containing_service=None,
    input_type=_UPDATEPARAMETERREQUEST,
    output_type=yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._PARAMETERTYPEINFO,
    serialized_options=b'\212\222\003z*</api/mdb-overrides/{instance}/{processor}/parameters/{name*}:\001*Z7*2/api/mdb/{instance}/{processor}/parameters/{name*}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAlgorithm',
    full_name='yamcs.protobuf.processing.MdbOverrideApi.UpdateAlgorithm',
    index=4,
    containing_service=None,
    input_type=_UPDATEALGORITHMREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003z*</api/mdb-overrides/{instance}/{processor}/algorithms/{name*}:\001*Z7*2/api/mdb/{instance}/{processor}/algorithms/{name*}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeMdbChanges',
    full_name='yamcs.protobuf.processing.MdbOverrideApi.SubscribeMdbChanges',
    index=5,
    containing_service=None,
    input_type=_SUBSCRIBEMDBCHANGESREQUEST,
    output_type=_MDBOVERRIDEINFO,
    serialized_options=b'\332\222\003\r\n\013mdb-changes',
  ),
])
_sym_db.RegisterServiceDescriptor(_MDBOVERRIDEAPI)

DESCRIPTOR.services_by_name['MdbOverrideApi'] = _MDBOVERRIDEAPI

# @@protoc_insertion_point(module_scope)
